netapp_ontap.models.log API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.log`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LogSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Log object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `format GET POST PATCH`

    The format in which the logs are generated by consolidation process. Possible values are:

    - xml - Data ONTAP-specific XML log format
    - evtx - Microsoft Windows EVTX log format

    Valid choices:

    - xml
    - evtx
  `links GET`

    The links field of the log.

  `retention GET POST PATCH`

    The retention field of the log.

  `rotation GET POST PATCH`

    The rotation field of the log.